pub trait Riptc { }Expand description
Marker trait for types that should be scanned by riptc despite
not being a direct dependency of a route.
This trait is automatically implemented for all items marked with the #[ript] attribute.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".